==> open-xchange-client-onboarding_7.8.2.orig.tar.bz2: open-xchange-client-onboarding-7.8.2/com.openexchange.client.onboarding.plist/src/com/openexchange/client/onboarding/plist/osgi/OnboardingPlistActivator.java <==
/*
 *
 *    OPEN-XCHANGE legal information
 *
 *    All intellectual property rights in the Software are protected by
 *    international copyright laws.
 *
 *
 *    In some countries OX, OX Open-Xchange, open xchange and OXtender
 *    as well as the corresponding Logos OX Open-Xchange and OX are registered
 *    trademarks of the OX Software GmbH group of companies.
 *    The use of the Logos is not covered by the GNU General Public License.
 *    Instead, you are allowed to use these Logos according to the terms and
 *    conditions of the Creative Commons License, Version 2.5, Attribution,
 *    Non-commercial, ShareAlike, and the interpretation of the term
 *    Non-commercial applicable to the aforementioned license is published
 *    on the web site http://www.open-xchange.com/EN/legal/index.html.
 *
 *    Please make sure that third-party modules and libraries are used
 *    according to their respective licenses.
 *
 *    Any modifications to this package must retain all copyright notices
 *    of the original copyright holder(s) for the original code used.
 *
 *    After any such modifications, the original and derivative code shall remain
 *    under the copyright of the copyright holder(s) and/or original author(s)per
 *    the Attribution and Assignment Agreement that can be located at
 *    http://www.open-xchange.com/EN/developer/. The contributing author shall be
 *    given Attribution for the derivative code and a license granting use.
 *
 *     Copyright (C) 2016-2020 OX Software GmbH
 *     Mail: info@open-xchange.com
 *
 *
 *     This program is free software; you can redistribute it and/or modify it
 *     under the terms of the GNU General Public License, Version 2 as published
 *     by the Free Software Foundation.
 *
 *     This program is distributed in the hope that it will be useful, but
 *     WITHOUT ANY WARRANTY; without even the implied warranty of MERCHANTABILITY
 *     or FITNESS FOR A PARTICULAR PURPOSE. See the GNU General Public License
 *     for more details.
 *
 *     You should have received a copy of the GNU General Public License along
 *     with this program; if not, write to the Free Software Foundation, Inc., 59
 *     Temple Place, Suite 330, Boston, MA 02111-1307 USA
 *
 */

package com.openexchange.client.onboarding.plist.osgi;

import org.osgi.service.http.HttpService;
import com.openexchange.client.onboarding.download.DownloadLinkProvider;
import com.openexchange.client.onboarding.plist.PListSigner;
import com.openexchange.client.onboarding.plist.download.PlistLinkProviderImpl;
import com.openexchange.client.onboarding.plist.internal.PListSignerImpl;
import com.openexchange.client.onboarding.plist.servlet.PListDownloadServlet;
import com.openexchange.client.onboarding.service.OnboardingService;
import com.openexchange.config.ConfigurationService;
import com.openexchange.config.cascade.ConfigViewFactory;
import com.openexchange.dispatcher.DispatcherPrefixService;
import com.openexchange.groupware.notify.hostname.HostnameService;
import com.openexchange.notification.mail.NotificationMailFactory;
import com.openexchange.osgi.HousekeepingActivator;
import com.openexchange.sms.SMSServiceSPI;
import com.openexchange.sms.tools.SMSBucketService;
import com.openexchange.user.UserService;


/**
 * {@link OnboardingPlistActivator}
 *
 * @author <a href="mailto:thorben.betten@open-xchange.com">Thorben Betten</a>
 * @since v7.8.1
 */
public class OnboardingPlistActivator extends HousekeepingActivator {

    private String downloadServletAlias;

    /**
     * Initializes a new {@link OnboardingPlistActivator}.
     */
    public OnboardingPlistActivator() {
        super();
    }

    @Override
    protected Class<?>[] getNeededServices() {
        return new Class<?>[] { NotificationMailFactory.class, ConfigViewFactory.class, ConfigurationService.class,
            DispatcherPrefixService.class, HttpService.class, OnboardingService.class, UserService.class };
    }

    @Override
    protected void startBundle() throws Exception {
        Services.setServiceLookup(this);

        // Track services needed for SMS transport
        trackService(SMSServiceSPI.class);
        trackService(SMSBucketService.class);
        trackService(DownloadLinkProvider.class);
        trackService(HostnameService.class);
        openTrackers();

        PListSignerImpl signerImpl = new PListSignerImpl();
        addService(PListSigner.class, signerImpl);
        registerService(PListSigner.class, signerImpl);

        // Register PLIST link provider
        registerService(DownloadLinkProvider.class, new PlistLinkProviderImpl(this));

        // Register plist download servlet
        PListDownloadServlet downloadServlet = new PListDownloadServlet(this);
        String prefix = getService(DispatcherPrefixService.class).getPrefix();
        downloadServletAlias = prefix + PListDownloadServlet.SERVLET_PATH;
        getService(HttpService.class).registerServlet(downloadServletAlias, downloadServlet, null, null);
    }

    @Override
    protected void stopBundle() throws Exception {
        HttpService httpService = getService(HttpService.class);
        if (httpService != null) {
            if (downloadServletAlias != null) {
                httpService.unregister(downloadServletAlias);
            }
        }
        super.stopBundle();
        removeService(PListSigner.class);
        Services.setServiceLookup(null);
    }

    @Override
    public <S> boolean addService(Class<S> clazz, S service) {
        return super.addService(clazz, service);
    }

    @Override
    public <S> boolean removeService(Class<? extends S> clazz) {
        return super.removeService(clazz);
    }

}

==> open-xchange-client-onboarding_7.10.4.orig.tar.bz2: open-xchange-client-onboarding-7.10.4/com.openexchange.client.onboarding.plist/src/com/openexchange/client/onboarding/plist/osgi/OnboardingPlistActivator.java <==
/*
 *
 *    OPEN-XCHANGE legal information
 *
 *    All intellectual property rights in the Software are protected by
 *    international copyright laws.
 *
 *
 *    In some countries OX, OX Open-Xchange, open xchange and OXtender
 *    as well as the corresponding Logos OX Open-Xchange and OX are registered
 *    trademarks of the OX Software GmbH group of companies.
 *    The use of the Logos is not covered by the GNU General Public License.
 *    Instead, you are allowed to use these Logos according to the terms and
 *    conditions of the Creative Commons License, Version 2.5, Attribution,
 *    Non-commercial, ShareAlike, and the interpretation of the term
 *    Non-commercial applicable to the aforementioned license is published
 *    on the web site http://www.open-xchange.com/EN/legal/index.html.
 *
 *    Please make sure that third-party modules and libraries are used
 *    according to their respective licenses.
 *
 *    Any modifications to this package must retain all copyright notices
 *    of the original copyright holder(s) for the original code used.
 *
 *    After any such modifications, the original and derivative code shall remain
 *    under the copyright of the copyright holder(s) and/or original author(s)per
 *    the Attribution and Assignment Agreement that can be located at
 *    http://www.open-xchange.com/EN/developer/. The contributing author shall be
 *    given Attribution for the derivative code and a license granting use.
 *
 *     Copyright (C) 2016-2020 OX Software GmbH
 *     Mail: info@open-xchange.com
 *
 *
 *     This program is free software; you can redistribute it and/or modify it
 *     under the terms of the GNU General Public License, Version 2 as published
 *     by the Free Software Foundation.
 *
 *     This program is distributed in the hope that it will be useful, but
 *     WITHOUT ANY WARRANTY; without even the implied warranty of MERCHANTABILITY
 *     or FITNESS FOR A PARTICULAR PURPOSE. See the GNU General Public License
 *     for more details.
 *
 *     You should have received a copy of the GNU General Public License along
 *     with this program; if not, write to the Free Software Foundation, Inc., 59
 *     Temple Place, Suite 330, Boston, MA 02111-1307 USA
 *
 */

package com.openexchange.client.onboarding.plist.osgi;

import org.osgi.service.http.HttpService;
import com.openexchange.client.onboarding.download.DownloadLinkProvider;
import com.openexchange.client.onboarding.plist.PListSigner;
import com.openexchange.client.onboarding.plist.download.PlistLinkProviderImpl;
import com.openexchange.client.onboarding.plist.internal.PListSignerImpl;
import com.openexchange.client.onboarding.plist.servlet.PListDownloadServlet;
import com.openexchange.client.onboarding.service.OnboardingService;
import com.openexchange.config.ConfigurationService;
import com.openexchange.config.cascade.ConfigViewFactory;
import com.openexchange.dispatcher.DispatcherPrefixService;
import com.openexchange.groupware.notify.hostname.HostnameService;
import com.openexchange.notification.mail.NotificationMailFactory;
import com.openexchange.osgi.HousekeepingActivator;
import com.openexchange.sms.SMSServiceSPI;
import com.openexchange.sms.tools.SMSBucketService;
import com.openexchange.user.UserService;


/**
 * {@link OnboardingPlistActivator}
 *
 * @author <a href="mailto:thorben.betten@open-xchange.com">Thorben Betten</a>
 * @since v7.8.1
 */
public class OnboardingPlistActivator extends HousekeepingActivator {

    private String downloadServletAlias;

    /**
     * Initializes a new {@link OnboardingPlistActivator}.
     */
    public OnboardingPlistActivator() {
        super();
    }

    @Override
    protected Class<?>[] getNeededServices() {
        return new Class<?>[] { NotificationMailFactory.class, ConfigViewFactory.class, ConfigurationService.class,
            DispatcherPrefixService.class, HttpService.class, OnboardingService.class, UserService.class };
    }

    @Override
    protected synchronized void startBundle() throws Exception {
        Services.setServiceLookup(this);

        // Track services needed for SMS transport
        trackService(SMSServiceSPI.class);
        trackService(SMSBucketService.class);
        trackService(DownloadLinkProvider.class);
        trackService(HostnameService.class);
        openTrackers();

        PListSignerImpl signerImpl = new PListSignerImpl();
        addService(PListSigner.class, signerImpl);
        registerService(PListSigner.class, signerImpl);

        // Register PLIST link provider
        registerService(DownloadLinkProvider.class, new PlistLinkProviderImpl(this));

        // Register plist download servlet
        PListDownloadServlet downloadServlet = new PListDownloadServlet(this);
        String prefix = getService(DispatcherPrefixService.class).getPrefix();
        downloadServletAlias = prefix + PListDownloadServlet.SERVLET_PATH;
        getService(HttpService.class).registerServlet(downloadServletAlias, downloadServlet, null, null);
    }

    @Override
    protected synchronized void stopBundle() throws Exception {
        if (downloadServletAlias != null) {
            HttpService httpService = getService(HttpService.class);
            if (httpService != null) {
                httpService.unregister(downloadServletAlias);
            }
        }
        removeService(PListSigner.class);
        super.stopBundle();
        Services.setServiceLookup(null);
    }

    @Override
    public <S> boolean addService(Class<S> clazz, S service) {
        return super.addService(clazz, service);
    }

    @Override
    public <S> boolean removeService(Class<? extends S> clazz) {
        return super.removeService(clazz);
    }

}
